import setuptools

setuptools.setup(
    name="investec",
    version="0.1.0",
    author="Kevin Smith",
    author_email="kevinsmith.kis@gmail.com",
    url="https://github.com/Aurelian-Shuttleworth/investec_banking_integration",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)